#!/bin/sh
export PATH='/sbin:/bin:/usr/sbin:/usr/bin:/usr/games:/usr/local/sbin:/usr/local/bin:/root/bin'
echo 'name: semigroupoids
version: 5.0.0.3
id: semigroupoids-5.0.0.3-fbc72ed4805b06eae441ee9bd856821c
key: semig_5N5EdCtvzkfJ5P7O7fIAGI
license: BSD3
copyright: Copyright (C) 2011-2015 Edward A. Kmett
maintainer: Edward A. Kmett <ekmett@gmail.com>
stability: provisional
homepage: http://github.com/ekmett/semigroupoids
synopsis: Semigroupoids: Category sans id
description:
    Provides a wide array of (semi)groupoids and operations for working with them.
    .
    A '\''Semigroupoid'\'' is a '\''Category'\'' without the requirement of identity arrows for every object in the category.
    .
    A '\''Category'\'' is any '\''Semigroupoid'\'' for which the Yoneda lemma holds.
    .
    When working with comonads you often have the @\<*\>@ portion of an @Applicative@, but
    not the @pure@. This was captured in Uustalu and Vene'\''s \"Essence of Dataflow Programming\"
    in the form of the @ComonadZip@ class in the days before @Applicative@. Apply provides a weaker invariant, but for the comonads used for data flow programming (found in the streams package), this invariant is preserved. Applicative function composition forms a semigroupoid.
    .
    Similarly many structures are nearly a comonad, but not quite, for instance lists provide a reasonable '\''extend'\'' operation in the form of '\''tails'\'', but do not always contain a value.
    .
    Ideally the following relationships would hold:
    .
    > Foldable ----> Traversable <--- Functor ------> Alt ---------> Plus           Semigroupoid
    >      |               |            |                              |                  |
    >      v               v            v                              v                  v
    > Foldable1 ---> Traversable1     Apply --------> Applicative -> Alternative      Category
    >                                   |               |              |                  |
    >                                   v               v              v                  v
    >                                 Bind ---------> Monad -------> MonadPlus          Arrow
    >
    .
    Apply, Bind, and Extend (not shown) give rise the Static, Kleisli and Cokleisli semigroupoids respectively.
    .
    This lets us remove many of the restrictions from various monad transformers
    as in many cases the binding operation or @\<*\>@ operation does not require them.
    .
    Finally, to work with these weaker structures it is beneficial to have containers
    that can provide stronger guarantees about their contents, so versions of '\''Traversable'\''
    and '\''Foldable'\'' that can be folded with just a '\''Semigroup'\'' are added.
category: Control, Comonads
author: Edward A. Kmett
exposed: True
exposed-modules:
    Data.Bifunctor.Apply Data.Functor.Alt Data.Functor.Apply
    Data.Functor.Bind Data.Functor.Bind.Class Data.Functor.Bind.Trans
    Data.Functor.Extend Data.Functor.Plus Data.Groupoid
    Data.Isomorphism Data.Semigroup.Bifoldable
    Data.Semigroup.Bitraversable Data.Semigroup.Foldable
    Data.Semigroup.Foldable.Class Data.Semigroup.Traversable
    Data.Semigroup.Traversable.Class Data.Semigroupoid
    Data.Semigroupoid.Dual Data.Semigroupoid.Ob
    Data.Semigroupoid.Static Data.Traversable.Instances
trusted: False
import-dirs: /usr/local/lib/cabal/ghc-7.10.2/semigroupoids-5.0.0.3
library-dirs: /usr/local/lib/cabal/ghc-7.10.2/semigroupoids-5.0.0.3
              /usr/local/lib
data-dir: /usr/local/share/cabal/ghc-7.10.2/semigroupoids-5.0.0.3
hs-libraries: HSsemigroupoids-5.0.0.3-5N5EdCtvzkfJ5P7O7fIAGI
include-dirs: /usr/local/include
depends:
    base-4.8.1.0-b8b97b99f1626bb4a12880f48ca36184
    base-orphans-0.4.4-61f87fbe40b70a96b4f01742198bd89e
    bifunctors-5-2b5356087f946c95acfd1c689bb6a6a9
    comonad-4.2.7.2-7dee90f058b530c7fd125fc1d8f7fafe
    containers-0.5.6.2-038ff4498ef87a6c587d93cd99a6573b
    contravariant-1.3.2-ce56e69c83e6634078c4687332c6f646
    distributive-0.4.4-8ccf7d9b4dba827f6bbdf2f9c6ea65a1
    semigroups-0.16.2.2-1ca08599864b70ede24d88606eededa0
    tagged-0.8.1-8fb7724b78ef88e44ca8950c77a173f6
    transformers-0.4.2.0-21dcbf13c43f5d8cf6a1f54dee6c5bff
    transformers-compat-0.4.0.4-3ca5cbcec233c17da785d5f27705643c
haddock-interfaces: /usr/local/share/doc/cabal/ghc-7.10.2/semigroupoids-5.0.0.3/html/semigroupoids.haddock
haddock-html: /usr/local/share/doc/cabal/ghc-7.10.2/semigroupoids-5.0.0.3/html
' | '/usr/local/bin/ghc-pkg' 'update' '-' '--global' '--no-user-package-db' "$@"
